@@ -1,6 +1,6 @@
-//$Id: bitmap-win.cc,v 1.15 2004/12/06 16:27:50 cactus Exp $ -*- c++ -*-
+//$Id: bitmap-win.cc,v 1.18 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -31,7 +31,7 @@
 #include <gtkmm/button.h>
 #include <gtkmm/frame.h>
 #include <gtkmm/box.h>
-#include <gtkmm/filechooserdialog.h>
+#include <gtkmm/messagedialog.h>
 
 #include "ui-gui.h"
 
@@ -76,8 +76,8 @@ GUI::BitmapWindow::BitmapWindow (Resources::Bitmap *res_):
     /* Preview of the image */
     Gtk::VBox *vbox = new Gtk::VBox (false, 5);
 
-    Gtk::Button *load_button = UI::create_stock_button (Gtk::Stock::OPEN, _("Load"));
-    export_button = UI::create_stock_button (Gtk::Stock::SAVE_AS, _("Export"));
+    Gtk::Button *load_button = UI::create_stock_button (Gtk::Stock::OPEN, _("_Load"));
+    export_button = UI::create_stock_button (Gtk::Stock::SAVE_AS, _("_Export"));
 
     Gtk::HBox *button_box = new Gtk::HBox (false, 5);    
     button_box->pack_start (*manage (load_button));
@@ -195,7 +195,7 @@ void GUI::BitmapWindow::export_image_cb ()
     g_free (title);
     
     file_chooser.add_button (Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
-    file_chooser.add_button (Gtk::Stock::OPEN, Gtk::RESPONSE_ACCEPT);
+    file_chooser.add_button (Gtk::Stock::SAVE, Gtk::RESPONSE_ACCEPT);
     file_chooser.set_default_response (Gtk::RESPONSE_ACCEPT);
     
     Gtk::FileFilter filter;
@@ -204,9 +204,6 @@ void GUI::BitmapWindow::export_image_cb ()
     file_chooser.add_filter (filter);
     file_chooser.set_local_only (false);
 
-    if (file_chooser.run () == Gtk::RESPONSE_ACCEPT)
-    {
-        // TODO: Show a warning before overwriting files
-        res->save_file_png (file_chooser.get_uri ());
-    }
+    if (UI::confirm_save (file_chooser))
+	res->save_file_png (file_chooser.get_uri ());
 }
