@@ -1,6 +1,6 @@
-//$Id: bitmapfamily-win-helpers.cc,v 1.1 2004/08/31 12:50:40 cactus Exp $ -*- c++ -*-
+//$Id: bitmapfamily-win-helpers.cc,v 1.3 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -63,7 +63,7 @@ void DepthList::update ()
          i != depth_list.end (); ++i, ++store_iter)
     {
         char *label_str;
-        if (res->get_image (i->first).isValid ())
+        if (res->get_image (i->first))
             label_str = g_strdup (i->second.c_str ());
         else
             label_str = g_strdup_printf (_("%s (unset)"), i->second.c_str ());
