@@ -1,6 +1,6 @@
-//$Id: bitmapfamily-win.cc,v 1.11 2004/12/06 16:27:50 cactus Exp $ -*- c++ -*-
+//$Id: bitmapfamily-win.cc,v 1.14 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -40,7 +40,7 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
 #include <gtkmm/alignment.h>
-#include <gtkmm/filechooserdialog.h>
+#include <gtkmm/messagedialog.h>
 #include <gtkmm/frame.h>
 #include <gtkmm/button.h>
 #include <gtkmm/buttonbox.h>
@@ -79,15 +79,15 @@ GUI::BitmapFamilyWindow::BitmapFamilyWindow (Resources::BitmapFamily *res_):
     /* Buttons */
     Gtk::Box *buttonbox = new Gtk::HBox (false, 5);
     main_vbox->pack_end (*manage (buttonbox), false, false);
-    load_button = UI::create_stock_button (Gtk::Stock::OPEN, _("Load"));
+    load_button = UI::create_stock_button (Gtk::Stock::OPEN, _("_Load"));
     load_button->signal_clicked ().connect (sigc::mem_fun (*this, &BitmapFamilyWindow::load_cb));
     buttonbox->add (*manage (load_button));
 
-    export_button = UI::create_stock_button (Gtk::Stock::SAVE_AS, _("Export"));
+    export_button = UI::create_stock_button (Gtk::Stock::SAVE_AS, _("_Export"));
     export_button->signal_clicked ().connect (sigc::mem_fun (*this, &BitmapFamilyWindow::export_cb));
     buttonbox->add (*manage (export_button));
 
-    remove_button = UI::create_stock_button (Gtk::Stock::REMOVE, _("Remove"));
+    remove_button = UI::create_stock_button (Gtk::Stock::REMOVE, _("_Remove"));
     remove_button->signal_clicked ().connect (sigc::mem_fun (*this, &BitmapFamilyWindow::remove_cb));
     buttonbox->add (*manage (remove_button));
 
@@ -215,7 +215,7 @@ void GUI::BitmapFamilyWindow::export_cb ()
     g_free (title);
     
     file_chooser.add_button (Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
-    file_chooser.add_button (Gtk::Stock::OPEN, Gtk::RESPONSE_ACCEPT);
+    file_chooser.add_button (Gtk::Stock::SAVE, Gtk::RESPONSE_ACCEPT);
     file_chooser.set_default_response (Gtk::RESPONSE_ACCEPT);
     
     Gtk::FileFilter filter;
@@ -224,11 +224,8 @@ void GUI::BitmapFamilyWindow::export_cb ()
     file_chooser.add_filter (filter);
     file_chooser.set_local_only (false);
 
-    if (file_chooser.run () == Gtk::RESPONSE_ACCEPT)
-    {
-        // TODO: Show a warning before overwriting files
-        res->save_file_png (type, file_chooser.get_uri ());
-    }
+    if (UI::confirm_save (file_chooser))
+	res->save_file_png (type, file_chooser.get_uri ());
 }
 
 void GUI::BitmapFamilyWindow::remove_cb ()
