@@ -1,6 +1,6 @@
-// $Id: cellrenderer-indent.h,v 1.3 2004/07/07 12:24:16 cactus Exp $ -*- c++ -*-
+// $Id: cellrenderer-indent.h,v 1.5 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -104,7 +104,7 @@ template<class RealCell>
 Guikachu::GUI::CellRendererIndent<RealCell>::CellRendererIndent ()
 {
     real_cell.property_mode ().signal_changed ().connect (
-        sigc::mem_fun (*this, &CellRendererIndentBase::real_cell_mode_changed_cb));
+        sigc::mem_fun (*this, &CellRendererIndent::real_cell_mode_changed_cb));
 }
 
 template<>
@@ -112,8 +112,8 @@ Guikachu::GUI::CellRendererIndent<Gtk::CellRendererText>::CellRendererIndent ();
 
 template<class RealCell>
 void Guikachu::GUI::CellRendererIndent<RealCell>::setup_view (Gtk::TreeView                           &treeview,
-                                                                    const Glib::ustring                     &title,
-                                                                    const Gtk::TreeViewColumn::SlotCellData &slot)
+                                                              const Glib::ustring                     &title,
+                                                              const Gtk::TreeViewColumn::SlotCellData &slot)
 {
     Gtk::CellRenderer *empty_cell = new Gtk::CellRendererText;
     Gtk::TreeView::Column *expander_col = new Gtk::TreeView::Column ("", *manage (empty_cell));
