@@ -1,6 +1,6 @@
-//$Id: form-editor-canvas.cc,v 1.17 2004/09/04 12:00:06 cactus Exp $ -*- c++ -*-
+//$Id: form-editor-canvas.cc,v 1.19 2005/07/29 09:54:15 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -60,9 +60,9 @@ namespace
 			  guint8           *target,
 			  int               target_rowstride);
 
-    Magick::Image bitmapref_to_image (const Properties::ResourceRef &ref_prop,
-                                      bool                           color,
-                                      Resources::Bitmap::BitmapType &bitmap_type);
+    Resources::Bitmap::ImageData bitmapref_to_image (const Properties::ResourceRef &ref_prop,
+						     bool                           color,
+						     Resources::Bitmap::BitmapType &bitmap_type);
 }
 
 Glib::RefPtr<Gdk::Pixbuf> FormEditor::render_text (const Font        &font,
@@ -443,16 +443,17 @@ Glib::RefPtr<Gdk::Pixbuf> render_text_multi_line_impl (const Font        &font,
 
 namespace // Image rendering utility functions
 {
-    typedef std::pair<Magick::Image, Guikachu::Resources::Bitmap::BitmapType> image_pair_t;
+    typedef std::pair<Guikachu::Resources::Bitmap::ImageData,
+		      Guikachu::Resources::Bitmap::BitmapType> image_pair_t;
     
 #define TRY_IMAGETYPE(t)                                                \
     image = res->get_image (Guikachu::Resources::Bitmap::TYPE_##t);     \
-    if (image.isValid ())                                               \
+    if (image)                                                          \
         return image_pair_t (image, Guikachu::Resources::Bitmap::TYPE_##t);
 
     image_pair_t get_grey_image (Guikachu::Resources::BitmapFamily *res)
     {
-        Magick::Image image;
+        Guikachu::Resources::Bitmap::ImageData image;
 
         TRY_IMAGETYPE(GREY_16);
         TRY_IMAGETYPE(GREY_4);
@@ -463,7 +464,7 @@ namespace // Image rendering utility functions
                                    
     image_pair_t get_color_image (Guikachu::Resources::BitmapFamily *res)
     {
-        Magick::Image image;
+        Guikachu::Resources::Bitmap::ImageData image;
 
         TRY_IMAGETYPE(COLOR_16K);
         TRY_IMAGETYPE(COLOR_256);
@@ -472,12 +473,12 @@ namespace // Image rendering utility functions
         return get_grey_image (res);
     }
 
-    Magick::Image bitmapref_to_image (const Properties::ResourceRef &ref_prop,
-                                      bool                           color,
-                                      Resources::Bitmap::BitmapType &bitmap_type)
+    Resources::Bitmap::ImageData bitmapref_to_image (const Properties::ResourceRef &ref_prop,
+						     bool                           color,
+						     Resources::Bitmap::BitmapType &bitmap_type)
     {
         Resource *res = ref_prop.resolve ();
-        Magick::Image image;
+        Resources::Bitmap::ImageData image;
         
         if (Resources::Bitmap *bitmap = dynamic_cast<Resources::Bitmap*> (res))
         {
@@ -512,38 +513,33 @@ FooCanvasmm::Item * FormEditor::draw_rectangle (FooCanvasmm::Group &group,
     return new FooCanvasmm::Polygon (group, points);
 }
 
-Glib::RefPtr<Gdk::Pixbuf> FormEditor::render_bitmap (const Magick::Image           &image,
-                                                     Resources::Bitmap::BitmapType  bitmap_type)
+Glib::RefPtr<Gdk::Pixbuf> FormEditor::render_bitmap (const Resources::Bitmap::ImageData &image,
+                                                     Resources::Bitmap::BitmapType       bitmap_type)
 {
-    if (!image.isValid ())
+    if (!image)
         return Glib::RefPtr<Gdk::Pixbuf> ();
 
-    unsigned int width = image.columns ();
-    unsigned int height = image.rows ();
-    guint8 *pixels = new guint8[width * height * 4];
-    
-    // Magick::Image::write is not a const method
-    const_cast<Magick::Image&>(image).write (0, 0, width, height,
-                                             "RGB", Magick::CharPixel, pixels);
+    unsigned int width = image->get_width ();
+    unsigned int height = image->get_height ();
+
     Glib::RefPtr<Gdk::Pixbuf> pixbuf = Gdk::Pixbuf::create (
         Gdk::COLORSPACE_RGB, false, 8, width, height);
 
-    dither_pixels (bitmap_type, pixbuf, pixels);
-    delete[] pixels;
+    dither_pixels (bitmap_type, image, pixbuf);
     
     return pixbuf->add_alpha (true, 0xFF, 0xFF, 0xFF);
-    return pixbuf;
+    // return pixbuf;
 }
 
-FooCanvasmm::Item * FormEditor::draw_bitmap (FooCanvasmm::Group            &group,
-                                             const Magick::Image           &image,
-                                             Resources::Bitmap::BitmapType  bitmap_type,
-                                             const Gdk::Color              &background_color,
-                                             int                            x,
-                                             int                            y,
-                                             int                            clip_width,
-                                             int                            clip_height,
-                                             Gtk::AnchorType                anchor)
+FooCanvasmm::Item * FormEditor::draw_bitmap (FooCanvasmm::Group                 &group,
+                                             const Resources::Bitmap::ImageData &image,
+                                             Resources::Bitmap::BitmapType       bitmap_type,
+                                             const Gdk::Color                   &background_color,
+                                             int                                 x,
+                                             int                                 y,
+                                             int                                 clip_width,
+                                             int                                 clip_height,
+                                             Gtk::AnchorType                     anchor)
 {
     Glib::RefPtr<Gdk::Pixbuf> pixbuf;
     Glib::RefPtr<Gdk::Pixbuf> pixbuf_img = render_bitmap (image, bitmap_type);
@@ -581,9 +577,9 @@ FooCanvasmm::Item * FormEditor::draw_bitmapref (FooCanvasmm::Group            &g
                                                 Gtk::AnchorType                anchor)
 {
     Resources::Bitmap::BitmapType bitmap_type;
-    Magick::Image image = bitmapref_to_image (ref_prop, color, bitmap_type);
+    Resources::Bitmap::ImageData image = bitmapref_to_image (ref_prop, color, bitmap_type);
     
-    if (!image.isValid ())
+    if (!image)
         return 0;
     
     return draw_bitmap (group, image, bitmap_type, background_color,
@@ -594,7 +590,7 @@ Glib::RefPtr<Gdk::Pixbuf> FormEditor::render_bitmapref (const Properties::Resour
                                                         bool                           color)
 {
     Resources::Bitmap::BitmapType bitmap_type;
-    Magick::Image image = bitmapref_to_image (ref_prop, color, bitmap_type);
+    Resources::Bitmap::ImageData image = bitmapref_to_image (ref_prop, color, bitmap_type);
 
     return render_bitmap (image, bitmap_type);
 }
