@@ -1,6 +1,6 @@
-//$Id: formbitmap-prop.cc,v 1.6 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
+//$Id: formbitmap-prop.cc,v 1.8 2005/07/29 09:54:15 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -23,7 +23,8 @@
 
 #include "property-ops-widget.h"
 
-#include "widgets/togglebutton.h"
+#include "usable-prop.h"
+
 #include "widgets/propertytable.h"
 #include "widgets/resource-combo.h"
 
@@ -53,11 +54,7 @@ FormBitmapProperties::FormBitmapProperties (FormBitmap *res):
 		    _("Select the bitmap resource to show"));
     
     /* Usable */
-    control = new GUI::PropertyEditors::ToggleButton (
-	res->usable,
-	new PropChangeOpFactory<bool> (_("Toggle usable state of %s"), res, res->usable, false));
-    proptable->add (_("_Usable:"), *manage (control),
-		    _("Non-usable widgets are not rendered by default"));
+    UsableProperties::add_controls (res, *proptable);
     
     /* Separator */
     proptable->add_separator ();
