@@ -1,6 +1,6 @@
-//$Id: gadget.cc,v 1.15 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: gadget.cc,v 1.17 2005/07/29 09:54:15 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -23,8 +23,8 @@ Gadget::Gadget (Resources::Form   *owner,
 		const std::string &id,
 		serial_t           serial):
     Widget (owner, id, serial),
-    ResizeableWidget (changed),
-    usable (changed, true)
+    Usable (changed),
+    ResizeableWidget (changed)
 {
     width = 20;
     height = 20;
