@@ -1,6 +1,6 @@
-//$Id: graffiti-canvas.cc,v 1.15 2004/06/12 16:33:38 cactus Exp $ -*- c++ -*-
+//$Id: graffiti-canvas.cc,v 1.17 2005/10/07 15:03:06 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -40,5 +40,6 @@ void GraffitiCanvasItem::draw (FooCanvasmm::Group &group) const
     Glib::RefPtr<Gdk::Pixbuf> pixbuf =
         Gdk::Pixbuf::create_from_xpm_data (graffiti_canvas_xpm);
     
-    new FooCanvasmm::Pixbuf (group, widget->x, widget->y, pixbuf);
+    FooCanvasmm::Pixbuf *pixbuf_item = new FooCanvasmm::Pixbuf (group, widget->x, widget->y, pixbuf);
+    pixbuf_item->property_interp_type () = Gdk::INTERP_NEAREST;
 }
