@@ -1,6 +1,6 @@
-//$Id: list-prop.cc,v 1.24 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
+//$Id: list-prop.cc,v 1.26 2005/07/29 09:54:15 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -23,10 +23,7 @@
 
 #include "widgets/entry.h"
 #include "widgets/num-entry.h"
-#include "widgets/pos-entry.h"
 #include "widgets/togglebutton.h"
-#include "widgets/size-entry.h"
-#include "widgets/auto-toggle.h"
 #include "widgets/propertytable.h"
 #include "widgets/string-list.h"
 #include "widgets/font-combo.h"
@@ -34,6 +31,7 @@
 #include <gtkmm/notebook.h>
 
 #include "auto-resizeable-prop.h"
+#include "usable-prop.h"
 
 #include "property-ops-widget.h"
 
@@ -69,11 +67,7 @@ ListProperties::ListProperties (List *res):
     proptable->add (_("_Visible items:"), *manage (control));
 
     /* Usable */
-    control = new GUI::PropertyEditors::ToggleButton (
-	res->usable,
-	new PropChangeOpFactory<bool> (_("Toggle usable state of %s"), res, res->usable, false));
-    proptable->add (_("_Usable:"), *manage (control),
-		    _("Non-usable widgets are not rendered by default"));
+    UsableProperties::add_controls (res, *proptable);
 
     /* Separator */
     proptable->add_separator ();
