@@ -1,6 +1,6 @@
-//$Id: palette.cc,v 1.20 2004/06/27 11:06:11 cactus Exp $ -*- c++ -*-
+//$Id: palette.cc,v 1.22 2005/07/29 09:54:15 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -99,10 +99,6 @@ Palette::Palette ():
 		       _("Vertical scroll bar"),
 		       0, 3);
 
-    PALETTE_ADD_BUTTON(Widgets::WIDGET_SCROLLBAR,
-		       _("Vertical scroll bar"),
-		       0, 3);
-
     PALETTE_ADD_BUTTON(Widgets::WIDGET_TABLE,
 		       _("Multi-column table"),
 		       1, 3);
@@ -111,10 +107,14 @@ Palette::Palette ():
 		       _("Bitmap"),
 		       2, 3);
 
+    PALETTE_ADD_BUTTON(Widgets::WIDGET_SLIDER,
+		       _("Slider"),
+		       0, 4);
+
     PALETTE_ADD_BUTTON(Widgets::WIDGET_GADGET,
 		       _("Custom widget"),
-		       0, 4);
-		       
+		       1, 4);
+
 #undef PALETTE_ADD_BUTTON
 
     vbox->add (*manage (table));
