@@ -1,6 +1,6 @@
-//$Id: pushbutton-prop.cc,v 1.24 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
+//$Id: pushbutton-prop.cc,v 1.26 2005/07/29 09:54:16 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -22,6 +22,8 @@
 #include <libgnome/libgnome.h>
 
 #include "auto-resizeable-prop.h"
+#include "usable-prop.h"
+#include "disabled-prop.h"
 #include "textual-prop.h"
 #include "graphical-prop.h"
 
@@ -52,21 +54,6 @@ PushButtonProperties::PushButtonProperties (PushButton *res):
     /* Bitmaps */
     GraphicalProperties::add_controls (res, *proptable);
     
-    /* Usable */
-    control = new GUI::PropertyEditors::ToggleButton (
-	res->usable,
-	new PropChangeOpFactory<bool> (_("Toggle usable state of %s"), res, res->usable, false));
-    proptable->add (_("_Usable:"), *manage (control),
-		    _("Non-usable widgets are not rendered by default"));
-
-    /* Anchor right */
-    control = new GUI::PropertyEditors::ToggleButton (
-	res->anchor_right,
-	new PropChangeOpFactory<bool> (_("Change alignment of %s"), res, res->anchor_right, false));
-    proptable->add (_("_Anchor right:"), *manage (control),
-		    _("Keep right aligned when changing label "
-		      "text at run-time"));
-
     /* Group ID */
     control = new GUI::PropertyEditors::NumEntry(
 	0, 65535, res->group,
@@ -76,6 +63,18 @@ PushButtonProperties::PushButtonProperties (PushButton *res):
 		      "per group (select 0 for non-exclusive "
 		      "buttons)"));
     
+    /* Anchor right */
+    control = new GUI::PropertyEditors::ToggleButton (
+	res->anchor_right,
+	new PropChangeOpFactory<bool> (_("Change alignment of %s"), res, res->anchor_right, false));
+    proptable->add (_("_Anchor right:"), *manage (control),
+		    _("Keep right aligned when changing label "
+		      "text at run-time"));
+
+    /* Usable */
+    UsableProperties::add_controls (res, *proptable);
+    DisabledProperties::add_controls (res, *proptable);
+    
     /* Separator */
     proptable->add_separator ();
 
