@@ -1,6 +1,6 @@
-//$Id: table-canvas.h,v 1.8 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: table-canvas.h,v 1.10 2005/07/29 09:54:16 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -32,13 +32,14 @@ namespace Guikachu
 	    class TableCanvasItem: public WidgetCanvasItem,
 				   public ResizeableCanvasItem
 	    {
-		Widgets::Table     *widget;
-		FooCanvasmm::Group *group;
+		Widgets::Table *widget;
+
 	    public:
 		TableCanvasItem (Widgets::Table     *widget,
 				 FooCanvasmm::Group &parent_group);
+
 	    protected:
-		virtual void update ();
+		virtual void draw (FooCanvasmm::Group &group) const;
 	    };
 	}
     }
