@@ -1,6 +1,6 @@
-//$Id: text-field.cc,v 1.22 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: text-field.cc,v 1.24 2005/07/29 09:54:16 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -26,12 +26,12 @@ using namespace Guikachu::GUI::FormEditor;
 TextField::TextField (Resources::Form   *owner,
 		      const std::string &id,
 		      serial_t           serial):
-    Widget (owner, id, serial),
     ResizeableWidget (changed),
+    Widget (owner, id, serial),
     AutoHeight (changed),
+    Usable (changed),
+    Disabled (changed),
     
-    usable (changed, true),
-
     font (changed, 0),
     editable (changed, true),
     multi_line (changed, false),
