@@ -1,6 +1,6 @@
-//$Id: form-win-layout.cc,v 1.7 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: form-win-layout.cc,v 1.9 2005/10/03 09:24:58 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -70,6 +70,30 @@ namespace
 	void undo ();
 	void redo ();
     };
+
+    enum CenterType
+    {
+        CENTER_HORIZONTAL,
+        CENTER_VERTICAL
+    };
+    
+    class CenterWidgetsOp: public UndoOp
+    {
+        ResourceManager    *manager;
+        serial_t            form_serial;
+        widget_positions_t  positions;
+
+        Glib::ustring op_label;
+
+    public:
+        CenterWidgetsOp (const std::set<Widget*> &widgets,
+                         CenterType               center_type);
+
+        Glib::ustring get_label () const { return op_label; };
+
+        void undo ();
+        void redo ();
+    };
     
 } // anonymous namespace
 
@@ -150,6 +174,74 @@ void AlignWidgetsOp::redo ()
     }    
 }
 
+CenterWidgetsOp::CenterWidgetsOp (const std::set<Widget*> &widgets,
+                                  CenterType               center_type) :
+    manager ((*widgets.begin ())->get_manager ()),
+    form_serial ((*widgets.begin ())->get_form ()->get_serial ())
+{
+    Resources::Form *form = (*widgets.begin ())->get_form ();
+    
+    char *str;
+
+    if (widgets.size () > 1)
+        str = g_strdup_printf (
+            center_type == CENTER_HORIZONTAL ? _("Center widgets of %s horizontally") : _("Center widgets of %s vertically"),
+            form->id ().c_str ());
+    else
+        str = g_strdup_printf (
+            center_type == CENTER_HORIZONTAL ? _("Center %s horizontally") : _("Center %s vertically"),
+            (*widgets.begin ())->id ().c_str ());
+            
+    op_label = str;
+    g_free (str);
+
+    for (std::set<Widget*>::const_iterator i = widgets.begin ();
+	 i != widgets.end (); ++i)
+    {
+	Widget *widget = *i;
+	
+	int new_x = widget->x;
+	int new_y = widget->y;
+
+	switch (center_type)
+	{
+	case CENTER_HORIZONTAL:
+	    new_x = (form->width - widget->get_width ()) / 2;
+	    break;
+	case CENTER_VERTICAL:
+	    new_y = (form->height - widget->get_height ()) / 2;
+            break;
+	}
+	
+	WidgetPosition pos_entry (widget, new_x, new_y);
+	positions.push_back (pos_entry);
+    }
+}
+
+void CenterWidgetsOp::undo ()
+{
+    Resources::Form *form = static_cast<Resources::Form*> (manager->get_resource (form_serial));
+    for (widget_positions_t::const_iterator i = positions.begin ();
+	 i != positions.end (); ++i)
+    {
+	Widget *widget = form->get_widget (i->widget_serial);
+	widget->x = i->old_x;
+	widget->y = i->old_y;
+    }
+}
+
+void CenterWidgetsOp::redo ()
+{
+    Resources::Form *form = static_cast<Resources::Form*> (manager->get_resource (form_serial));
+    for (widget_positions_t::const_iterator i = positions.begin ();
+	 i != positions.end (); ++i)
+    {
+	Widget *widget = form->get_widget (i->widget_serial);
+	widget->x = i->new_x;
+	widget->y = i->new_y;
+    }    
+}
+
 namespace
 {
     bool compare_left (Guikachu::Widget *p, Guikachu::Widget *q)
@@ -212,3 +304,15 @@ void FormWindow::align_bottom ()
     res->get_manager ()->get_undo_manager ().push (
 	new AlignWidgetsOp (selection, ALIGN_BOTTOM, bottom));
 }
+
+void FormWindow::center_horizontal ()
+{
+    res->get_manager ()->get_undo_manager ().push (
+        new CenterWidgetsOp (selection, CENTER_HORIZONTAL));
+}
+
+void FormWindow::center_vertical ()
+{
+    res->get_manager ()->get_undo_manager ().push (
+        new CenterWidgetsOp (selection, CENTER_VERTICAL));
+}
