@@ -1,6 +1,6 @@
-//$Id: form-win-widgettree.cc,v 1.6 2004/06/27 11:06:11 cactus Exp $ -*- c++ -*-
+//$Id: form-win-widgettree.cc,v 1.9 2005/10/07 15:37:39 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -107,11 +107,28 @@ void WidgetTreeWrapper::widget_removed_cb (Guikachu::Widget *widget)
     
     treestore->erase (row_found->second);
     row_map.erase (row_found);
+
+    treeview.expand_all ();
+}
+
+bool WidgetTreeWrapper::compare_treerow (const Gtk::TreeRow &row, Guikachu::Widget *widget) const
+{
+    Widget *curr_widget = row[col_widget];
+    if (!curr_widget)
+        return true;
+    
+    return IDManager::NoCase () (curr_widget->id, widget->id);
+}
+
+Gtk::TreeStore::iterator WidgetTreeWrapper::get_place (Guikachu::Widget *widget) const
+{
+    return std::lower_bound (root_tree.children ().begin (), root_tree.children ().end (),
+                             widget, sigc::mem_fun (*this, &WidgetTreeWrapper::compare_treerow));    
 }
 
 void WidgetTreeWrapper::widget_created_cb (Guikachu::Widget *widget)
 {
-    Gtk::TreeRow row = *(treestore->append (root_tree.children ()));
+    Gtk::TreeRow row = *(treestore->insert (get_place (widget)));
     row[col_widget] = widget;
 
     row_map[widget] = row;
@@ -120,13 +137,26 @@ void WidgetTreeWrapper::widget_created_cb (Guikachu::Widget *widget)
 	sigc::mem_fun (*this, &WidgetTreeWrapper::widget_changed_cb), row));
     widget->selected.connect (sigc::bind (
 	sigc::mem_fun (*this, &WidgetTreeWrapper::widget_selected_cb), widget));
-    
+
     treeview.expand_all ();
 }
 
 void WidgetTreeWrapper::widget_changed_cb (Gtk::TreeRow row)
 {
-    treestore->row_changed (treestore->get_path (row), row);
+    bool selected = treeview.get_selection ()->is_selected (row);
+
+    Widget *widget = row[col_widget];
+    g_return_if_fail (widget);
+
+    treestore->erase (row);            
+    row = *(treestore->insert (get_place (widget)));
+    row[col_widget] = widget;
+    row_map[widget] = row;
+
+    treeview.expand_all ();
+    
+    if (selected)
+        treeview.get_selection ()->select (row);
 }
 
 void WidgetTreeWrapper::form_changed_cb ()
