@@ -1,6 +1,6 @@
-//$Id: form-win.cc,v 1.70 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
+//$Id: form-win.cc,v 1.72 2005/10/03 09:24:58 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -50,6 +50,8 @@
 #include "pixmaps/menu-align-right.xpm"
 #include "pixmaps/menu-align-top.xpm"
 #include "pixmaps/menu-align-bottom.xpm"
+#include "pixmaps/menu-center-horizontal.xpm"
+#include "pixmaps/menu-center-vertical.xpm"
 
 #include "form-editor/widget-factory.h"
 
@@ -463,6 +465,14 @@ void FormWindow::widget_menu_cb (guint    button,
 	Gnome::UI::Items::Item (Gnome::UI::Items::Icon (Gtk::Stock::DELETE),
 				_("_Remove"),
 				sigc::bind (sigc::mem_fun (*this, &FormWindow::widget_remove_cb), widget)));
+
+    popup_menu_list.push_back (Gnome::UI::Items::Separator ());
+    popup_menu_list.push_back (Gnome::UI::Items::Item (
+                                   Gnome::UI::Items::IconXpm (menu_center_horizontal_xpm),
+                                   _("Center _horizontally"), sigc::mem_fun (*this, &FormWindow::center_horizontal)));
+    popup_menu_list.push_back (Gnome::UI::Items::Item (
+                                   Gnome::UI::Items::IconXpm (menu_center_vertical_xpm),
+                                   _("Center _vertically"), sigc::mem_fun (*this, &FormWindow::center_vertical)));
     
     if (selection.size () > 1 && selection.find (widget) != selection.end ())
     {
