@@ -1,6 +1,6 @@
-//$Id: form-win.h,v 1.41 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
+//$Id: form-win.h,v 1.43 2005/10/03 09:24:58 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -116,6 +116,8 @@ namespace Guikachu
 	    void align_right  ();
 	    void align_top    ();
 	    void align_bottom ();
+            void center_horizontal ();
+            void center_vertical   ();
 	    
 	    // Selection managment
 	    void selection_add    (Widget *widget);
