@@ -1,6 +1,6 @@
-//$Id: io.cc,v 1.12 2004/09/25 08:46:42 cactus Exp $ -*- c++ -*-
+//$Id: io.cc,v 1.14 2005/07/29 09:54:17 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -93,6 +93,17 @@ void IO::save_uri (const Glib::ustring &uri, const unsigned char *data, Gnome::V
     }
 }
 
+bool IO::uri_exists (const Glib::ustring &uri)
+{
+    try {
+	Glib::RefPtr<Gnome::Vfs::FileInfo> fileinfo = Gnome::Vfs::Handle::get_file_info (uri);
+	return true;
+    } catch (...) {
+    }
+
+    return false;
+}
+
 IO::IOFactory * IO::IOFactory::instance_ = 0;
 
 namespace
