@@ -1,6 +1,6 @@
-//$Id: xml-loader.cc,v 1.13 2004/08/20 18:22:17 cactus Exp $ -*- c++ -*-
+//$Id: xml-loader.cc,v 1.15 2005/10/08 16:16:09 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -125,12 +125,31 @@ static void load_app (Resources::Application *app, const StorageNode &node)
     app->version =  "";
     app->vendor =   "";
 
+    class TagHandler: public StorageProcessor::NodeHandler
+    {
+        Resources::Application::tag_map_t &tags;
+    public:
+	TagHandler (Resources::Application::tag_map_t &tags_) :
+	    tags (tags_)
+	    {};
+	
+	void operator() (const StorageNode &node)
+	    {
+                for (StorageNode i = node.children (); i; ++i)
+                    if (i.name () == "tag")
+                        tags[i.get_prop_string ("name")] = i.get_prop_string ("val");
+	    };
+    };
+    Resources::Application::tag_map_t tags;
+    
     StorageProcessor processor;
     processor.add_handler ("iconname", new StorageNodeHandlers::StringContents (app->iconname));
     processor.add_handler ("version",  new StorageNodeHandlers::StringContents (app->version));
     processor.add_handler ("vendor",   new StorageNodeHandlers::StringContents (app->vendor));
+    processor.add_handler ("tags",     new TagHandler (tags));
 
     processor.run (node);
+    app->add_tags (tags);
 }
 
 static void load_target (Target *target, const StorageNode &node)
