@@ -1,6 +1,6 @@
-//$Id: mainwin-io.cc,v 1.39 2004/08/20 18:22:17 cactus Exp $ -*- c++ -*-
+//$Id: mainwin-io.cc,v 1.42 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -21,6 +21,7 @@
 
 #include "mainwin.h"
 #include "ui.h"
+#include "ui-gui.h"
 
 #include "resource-manager.h"
 #include "session.h"
@@ -113,22 +114,15 @@ bool GUI::MainWin::check_save ()
     static const int cancel_btn_num = 1;
     static const int save_btn_num = 2;
 
-    Gtk::Button *discard_btn = new Gtk::Button;
-    Gtk::HBox *hbox = new Gtk::HBox (false, 5);
-    hbox->add (*manage (new Gtk::Image (Gtk::Stock::DELETE, Gtk::ICON_SIZE_BUTTON)));
-    hbox->add (*manage (new Gtk::Label (_("_Don't Save"), true)));
-    discard_btn->add (*manage (hbox));
-    discard_btn->show_all ();
+    Gtk::Button *discard_btn = UI::create_stock_button (Gtk::Stock::DELETE,
+                                                        _("_Don't Save"));
+    discard_btn->show ();
     
     dialog->add_action_widget (*manage (discard_btn), discard_btn_num);
     dialog->add_button (Gtk::Stock::CANCEL, cancel_btn_num);
     dialog->add_button (Gtk::Stock::SAVE, save_btn_num);
     dialog->set_default_response (save_btn_num);
 
-#if 0
-    gnome_dialog_grab_focus (dialog->gtkobj (), save_btn);
-#endif
-
     dialog->set_position (Gtk::WIN_POS_CENTER_ON_PARENT);
     response = dialog->run ();
     dialog->hide ();
@@ -191,7 +185,7 @@ void GUI::MainWin::save_as_cb ()
     file_chooser.add_filter (filter_all);
     
     file_chooser.set_local_only (false);
-    if (file_chooser.run () == Gtk::RESPONSE_ACCEPT)
+    if (UI::confirm_save (file_chooser))
         Guikachu::Main::instance ()->save_doc (file_chooser.get_uri ());
 }
     
