@@ -1,6 +1,6 @@
-//$Id: mainwin.cc,v 1.53 2004/07/12 22:07:57 cactus Exp $ -*- c++ -*-
+//$Id: mainwin.cc,v 1.59 2005/10/09 15:28:28 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -30,6 +30,7 @@
 #include <list>
 
 #include "resource-manager.h"
+#include "resource-util.h"
 
 #include "add-resource.h"
 #include "preferences-win.h"
@@ -43,6 +44,11 @@ using namespace Guikachu;
 namespace {
 
     Glib::ustring escape_underscores (const Glib::ustring &text);
+
+    enum {
+        STATUSBAR_DEFAULT,
+        STATUSBAR_TREESELECTION
+    };
     
 } // Anonymous namespace
 
@@ -51,7 +57,9 @@ GUI::MainWin::MainWin ():
     manager (0),
     uri (""),
     in_exit (false),
-    recent_files_num (0)   
+    recent_files_num (0),
+    view_mode_sort (0),
+    view_mode_group (0)
 {
     /* File menu */
     Gnome::UI::Items::Info m_file[] = {
@@ -85,11 +93,23 @@ GUI::MainWin::MainWin ():
 	Gnome::UI::MenuItems::Cut    (sigc::mem_fun (*this, &MainWin::cut_cb)),
 	Gnome::UI::MenuItems::Copy   (sigc::mem_fun (*this, &MainWin::copy_cb)),
 	Gnome::UI::MenuItems::Paste  (sigc::mem_fun (*this, &MainWin::paste_cb)),
+
+        Gnome::UI::Items::Separator  (),
+	Gnome::UI::MenuItems::Preferences (sigc::mem_fun (*this, &MainWin::preferences_cb))        
     };
-    
-    /* Settings menu */
-    Gnome::UI::Items::Info m_settings[] = {
-	Gnome::UI::MenuItems::Preferences (sigc::mem_fun (*this, &MainWin::preferences_cb))
+
+    /* View menu */
+    Gnome::UI::Items::Info m_viewmode[] = {
+        Gnome::UI::Items::Item       (_("_Sort by ID"),
+                                      sigc::bind (sigc::mem_fun (*this, &MainWin::set_view_mode), false),
+                                      _("Show resources in a sorted list")),
+        Gnome::UI::Items::Item       (_("_Group by type"),
+                                      sigc::bind (sigc::mem_fun (*this, &MainWin::set_view_mode), true),
+                                      _("Show resources grouped by their type"))
+    };
+
+    Gnome::UI::Items::Info m_view[] = {
+        Gnome::UI::Items::RadioTree (m_viewmode)
     };
     
     /* Help menu */
@@ -101,14 +121,22 @@ GUI::MainWin::MainWin ():
     Gnome::UI::Items::SubTree menubar[] = {
 	Gnome::UI::Menus::File     (m_file),
 	Gnome::UI::Menus::Edit     (m_edit),
-	Gnome::UI::Menus::Settings (m_settings),
+        Gnome::UI::Menus::View     (m_view),
 	Gnome::UI::Menus::Help     (m_help)
-    };    
-    create_menus (menubar);
+    };
+
+    /* Thar be dragons here */
+    Gnome::UI::Items::Array<Gnome::UI::Items::SubTree> &menubar_infos = create_menus (menubar);
+    {
+        Gnome::UI::Items::Info &view_radiogroup = menubar_infos[2].get_uitree ()[0];
+        GnomeUIInfo &view_radiogroup_gobj = view_radiogroup;
+        GnomeUIInfo *view_modelist_gobj = static_cast<GnomeUIInfo*>(view_radiogroup_gobj.moreinfo);
+        view_mode_sort = Glib::wrap (GTK_CHECK_MENU_ITEM (view_modelist_gobj[1].widget));
+        view_mode_group = Glib::wrap (GTK_CHECK_MENU_ITEM (view_modelist_gobj[2].widget));
+    }
 
-    
     /* Create status bar */
-    set_statusbar (*manage (new Gtk::Statusbar));
+    set_statusbar (statusbar);
     install_menu_hints ();
 
     
@@ -139,6 +167,10 @@ GUI::MainWin::MainWin ():
 	sigc::mem_fun (*this, &MainWin::update_recent_files));
     update_recent_files ();
 
+    // Update resourcetree mode
+    Preferences::MainWin::get_default_grouped () ?
+        view_mode_group->set_active (true) : view_mode_sort->set_active (true);
+
     // Scrollable viewport
     Gtk::ScrolledWindow *scrollwin = new Gtk::ScrolledWindow ();
     scrollwin->set_policy (Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
@@ -146,6 +178,9 @@ GUI::MainWin::MainWin ():
     scrollwin->show_all ();
     set_contents (*manage (scrollwin));
     set_size_request (300, 300);
+
+    resource_tree.get_selection ()->signal_changed ().connect (
+        sigc::mem_fun (*this, &MainWin::tree_selection_changed_cb));
 }
 
 void GUI::MainWin::set_manager (ResourceManager *manager_)
@@ -156,6 +191,13 @@ void GUI::MainWin::set_manager (ResourceManager *manager_)
 
     resource_tree.set_manager (manager);
 
+    // Is there a resourcetree mode stored in the file?
+    std::string resourcetree_mode = manager->get_application ()->get_tag ("guikachu:resourcetree-mode");
+    if (resourcetree_mode == "sort")
+        view_mode_sort->set_active (true);
+    else if (resourcetree_mode == "group")
+        view_mode_group->set_active (true);
+    
     // Listen for changes in the undo stack
     manager->get_undo_manager ().changed.connect (sigc::mem_fun (*this, &MainWin::update_undo));
     update_undo ();
@@ -226,13 +268,15 @@ void GUI::MainWin::update_undo ()
     std::string edit_str = dgettext ("libgnomeui-2.0", "_Edit");
     edit_str += '/';
     remove_menu_range (edit_str, 0, 2);
+
+    Gnome::UI::Items::Item undo_item (Gnome::UI::Items::Icon (Gtk::Stock::UNDO), undo_label.get (),
+                                      sigc::mem_fun (*this, &MainWin::undo_cb));
+    Gnome::UI::Items::Item redo_item (Gnome::UI::Items::Icon (Gtk::Stock::REDO), redo_label.get (),
+                                      sigc::mem_fun (*this, &MainWin::redo_cb));
+    undo_item.set_accel (Gtk::AccelKey ('z', Gdk::CONTROL_MASK));
+    redo_item.set_accel (Gtk::AccelKey ('z', Gdk::CONTROL_MASK | Gdk::SHIFT_MASK));
     
-    Gnome::UI::Items::Info undo_items[] = {
-	Gnome::UI::Items::Item (Gnome::UI::Items::Icon (Gtk::Stock::UNDO), undo_label.get (),
-				sigc::mem_fun (*this, &MainWin::undo_cb)),
-	Gnome::UI::Items::Item (Gnome::UI::Items::Icon (Gtk::Stock::REDO), redo_label.get (),
-				sigc::mem_fun (*this, &MainWin::redo_cb)),
-    };
+    Gnome::UI::Items::Info undo_items[] = { undo_item, redo_item };
 
     Gnome::UI::Items::Array<Gnome::UI::Items::Info> menubar_widgets =
 	insert_menus (edit_str, undo_items);
@@ -266,6 +310,15 @@ void GUI::MainWin::preferences_cb ()
     pref_win.run ();
 }
 
+void GUI::MainWin::set_view_mode (bool grouped)
+{
+    if (manager)
+        manager->get_application ()->set_tag ("guikachu:resourcetree-mode",
+                                              grouped ? "group" : "sort");
+
+    resource_tree.set_grouped (grouped);
+}
+
 void GUI::MainWin::update_title ()
 {
     gchar *title_buf;
@@ -283,6 +336,16 @@ void GUI::MainWin::update_title ()
     g_free (title_buf);
 }
 
+void GUI::MainWin::tree_selection_changed_cb ()
+{
+    statusbar.pop (STATUSBAR_TREESELECTION);
+    if (Resource *res = resource_tree.get_selected ())
+    {
+        Glib::ustring s = res->id () + ": " + Resources::display_name_from_type (res->get_type ());        
+        statusbar.push (s, STATUSBAR_TREESELECTION);
+    }
+}
+
 namespace {
 
 Glib::ustring escape_underscores (const Glib::ustring &text)
