@@ -1,6 +1,6 @@
-//$Id: mainwin.h,v 1.25 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: mainwin.h,v 1.31 2005/10/09 11:57:50 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -21,6 +21,7 @@
 
 #include <libgnomeuimm/app.h>
 #include <gtkmm/fileselection.h>
+#include <gtkmm/statusbar.h>
 #include "resource-tree.h"
 #include "resource.h"
 #include "resource-manager.h"
@@ -34,17 +35,19 @@ namespace Guikachu
 	{
 	    ResourceManager *manager;
 	    
-	    Glib::ustring filename, desired_filename;
+	    Glib::ustring uri;
 	    bool          in_exit;
 
 	    int recent_files_num;
 
 	    ResourceTree resource_tree;
+            Gtk::CheckMenuItem *view_mode_sort, *view_mode_group;
+            Gtk::Statusbar statusbar;
 	    
 	public:
 	    MainWin ();
-	    void set_filename (const Glib::ustring& filename);
-	    void set_manager  (ResourceManager *manager);
+	    void set_uri     (const Glib::ustring& uri);
+	    void set_manager (ResourceManager *manager);
 	    
 	private:
 	    void update_recent_files ();
@@ -52,6 +55,8 @@ namespace Guikachu
 	    
 	    void update_title ();
 
+            void tree_selection_changed_cb ();
+
 	    bool on_delete_event (GdkEventAny *e);
 
 	    void exit_cb ();
@@ -71,14 +76,11 @@ namespace Guikachu
 	    
 	    void preferences_cb ();
 
-	    void open (Glib::ustring filename,
-                       std::string   mime_type);
-
-	    void filesel_save_cb   (Gtk::FileSelection *fs);
-	    void filesel_close_cb  (Gtk::FileSelection *fs);
-	    void filesel_export_cb (Gtk::FileSelection *fs);
+	    void open (Glib::ustring uri);
 	    
 	    bool check_save ();
+
+            void set_view_mode (bool grouped);
 	};
     }
 }
