@@ -1,6 +1,6 @@
-//$Id: menu-win.h,v 1.15 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: menu-win.h,v 1.19 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -38,7 +38,7 @@ namespace Guikachu
     namespace GUI
     {
 	class MenuWindow: public ResourceWindow,
-			  public SigC::Object
+			  public sigc::trackable
 	{
 	    Resources::Menu *res;
 
@@ -53,9 +53,6 @@ namespace Guikachu
 	    Gtk::Label  *lbl_item_label, *lbl_item_id, *lbl_item_shortcut;
 	    Gtk::Button *btnSubmenu, *btnItem, *btnSeparator;
 
-	    Gtk::TreeModelColumn<Glib::ustring> col_label;
-	    Gtk::TreeModelColumn<Glib::ustring> col_id;
-	    Gtk::TreeModelColumn<Glib::ustring> col_shortcut;
 	    Gtk::TreeModelColumn<bool>          col_is_submenu;
 	    Gtk::TreeModelColumn<unsigned int>  col_index;
 	    Gtk::TreeModelColumn<unsigned int>  col_parent_index;
@@ -68,24 +65,38 @@ namespace Guikachu
 	    ~MenuWindow ();
 
 	    void show ();
-	private:
-	    void delete_event_impl (GdkEventAny *e);
 
+	private:
             Gtk::Entry *current_entry;
             int         current_entry_pos;
 	    int         update_block;
+
 	    void update ();
             
+	    void id_entry_cb ();
+	    void item_label_entry_cb ();
+	    void item_id_entry_cb ();
+	    void item_shortcut_entry_cb ();
+
+            void cell_label_cb    (Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter) const;
+            void cell_id_cb       (Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter) const;
+            void cell_shortcut_cb (Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter) const;
+
+            void cell_label_edit_cb    (const Glib::ustring &path, const Glib::ustring &new_text);
+            void cell_id_edit_cb       (const Glib::ustring &path, const Glib::ustring &new_text);
+            void cell_shortcut_edit_cb (const Glib::ustring &path, const Glib::ustring &new_text);
+            
+	    void delete_event_impl (GdkEventAny *e);
+            
 	    void reset_controls ();
 
             void entry_insert_cb (const Glib::ustring &text, int *pos, Gtk::Entry *entry);
             void entry_delete_cb (int start_pos, int end_pos, Gtk::Entry *entry);
             
-	    void id_entry_cb ();
-	    void item_id_entry_cb ();
-	    void item_label_entry_cb ();
-	    void item_shortcut_entry_cb ();
-	    
+            void set_item_label    (const Gtk::TreeModel::iterator &iter, const std::string &new_label);
+            void set_item_id       (const Gtk::TreeModel::iterator &iter, const std::string &new_id);
+            void set_item_shortcut (const Gtk::TreeModel::iterator &iter, const std::string &new_shortcut);
+            
 	    void btn_up_cb ();
 	    void btn_down_cb ();
 	    void btn_remove_cb ();
