@@ -1,6 +1,6 @@
-//$Id: preferences.cc,v 1.16 2004/07/12 22:07:57 cactus Exp $ -*- c++ -*-
+//$Id: preferences.cc,v 1.19 2005/10/03 14:50:06 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -18,7 +18,7 @@
 
 #include "preferences.h"
 
-#include <gconf/gconf-client.h>
+#include <gconfmm/client.h>
 #include <algorithm>
 
 #include <iostream>
@@ -27,23 +27,7 @@ namespace Guikachu
 {
     namespace Preferences
     {
-	namespace Interface
-	{
-	    static void gconf_recent_files_cb (GConfClient  *client,
-					       unsigned int  conn_id,
-					       GConfEntry   *entry,
-					       gpointer      user_data);
-	}
-	
-	namespace FormEditor
-	{
-	    static void gconf_color_cb (GConfClient  *client,
-					unsigned int  cnxn_id,
-					GConfEntry   *entry,
-					gpointer      user_data);	    
-	}
-
-	GConfClient *gconf_client;
+	Glib::RefPtr<Gnome::Conf::Client> gconf_client;
 
 	static std::string get_gconf_string (const std::string &key);
     }
@@ -57,62 +41,32 @@ using namespace Guikachu;
 void Preferences::init ()
 {
     // Set up GConf client
-    gconf_client = gconf_client_get_default ();
-    gconf_client_add_dir (gconf_client, "/apps/guikachu",
-			  GCONF_CLIENT_PRELOAD_RECURSIVE, 0);
+    gconf_client = Gnome::Conf::Client::get_default_client ();
+    gconf_client->add_dir ("/apps/guikachu", Gnome::Conf::CLIENT_PRELOAD_RECURSIVE);
     
     // Set up GConf callbacks
     // User interface
-    gconf_client_notify_add (gconf_client, GCONF_ROOT "/Interface",
-			     Interface::gconf_recent_files_cb,
-			     0, 0, 0);
+    gconf_client->notify_add (GCONF_ROOT "/Interface",
+                              sigc::hide (sigc::hide (Interface::recent_files_changed.make_slot ())));
     
     // Colors
-    gconf_client_notify_add (gconf_client, GCONF_ROOT GCONF_COLORS_ROOT,
-			     FormEditor::gconf_color_cb,
-			     0, 0, 0);
-}
-
-void Preferences::shutdown ()
-{
-    g_object_unref (G_OBJECT (gconf_client));
+    gconf_client->notify_add (GCONF_ROOT GCONF_COLORS_ROOT,
+                              sigc::hide (sigc::hide (FormEditor::colors_changed.make_slot ())));
 }
 
 std::string Preferences::get_gconf_string (const std::string &key)
 {
     std::string real_key = GCONF_ROOT + key;
-    char *value = gconf_client_get_string (gconf_client, real_key.c_str (), 0);
-
-    if (value)
-	return value;
-    else
-	return "";
+    return gconf_client->get_string (real_key);;
 }
 
 
 
 sigc::signal0<void> Preferences::Interface::recent_files_changed;
 
-static void Preferences::Interface::gconf_recent_files_cb (GConfClient  *client,
-							   unsigned int  conn_id,
-							   GConfEntry   *entry,
-							   gpointer      user_data)
-{
-    recent_files_changed.emit ();
-}
-
 Preferences::Interface::RecentFiles Preferences::Interface::get_recent_files ()
 {
-    RecentFiles retval;
-    
-    GSList *gconf_list = gconf_client_get_list (gconf_client,
-						GCONF_ROOT "/Interface/recent_files",
-						GCONF_VALUE_STRING, 0);
-
-    for (GSList *i = gconf_list; i; i = g_slist_next (i))
-        retval.push_back ((char*)i->data);
-
-    return retval;
+    return gconf_client->get_string_list (GCONF_ROOT "/Interface/recent_files");
 }
 
 void Preferences::Interface::add_recent_file (const Glib::ustring &uri)
@@ -129,8 +83,7 @@ void Preferences::Interface::add_recent_file (const Glib::ustring &uri)
     recent_list.push_front (uri);
     
     // Truncate list
-    int recent_list_size = gconf_client_get_int (
-	gconf_client, GCONF_ROOT "/Interface/recent_files_size", 0);
+    int recent_list_size = gconf_client->get_int (GCONF_ROOT "/Interface/recent_files_size");
     int pos;
     RecentFiles::iterator truncate_begin;
 
@@ -142,27 +95,22 @@ void Preferences::Interface::add_recent_file (const Glib::ustring &uri)
     if (truncate_begin != recent_list.end ())
 	recent_list.erase (truncate_begin, recent_list.end ());
 
-    // Save new list in GConf
-    GSList *c_recent_list = 0, *c_i = 0;
-    for (RecentFiles::const_iterator i = recent_list.begin (); i != recent_list.end (); i++)
-    {
-	if (!c_recent_list)
-	    c_recent_list = c_i = g_slist_append (c_i, (void*)(i->c_str ()));
-	else
-	    c_i = g_slist_append (c_i, (void*)(i->c_str ()));
-    }
+    Gnome::Conf::Value gval (Gnome::Conf::VALUE_LIST);
+    gval.set_list_type (Gnome::Conf::VALUE_STRING);
+    gval.set_string_list (recent_list);
 
-    gconf_client_set_list (gconf_client, GCONF_ROOT "/Interface/recent_files",
-			   GCONF_VALUE_STRING, c_recent_list, 0); 
-
-    g_slist_free (c_recent_list);
+    gconf_client->set (GCONF_ROOT "/Interface/recent_files", gval);
 }
 
 int Preferences::Interface::get_undo_size ()
 {
-    return gconf_client_get_int (gconf_client, GCONF_ROOT "/Interface/undo_size", 0);
+    return gconf_client->get_int (GCONF_ROOT "/Interface/undo_size");
 }
 
+bool Preferences::MainWin::get_default_grouped ()
+{
+    return gconf_client->get_bool (GCONF_ROOT "/MainWin/default_grouped");
+}
 
 
 sigc::signal0<void> Preferences::FormEditor::colors_changed;
@@ -172,7 +120,7 @@ void Preferences::FormEditor::set_colors (const std::string &color_fg,
 					  const std::string &color_bg,
 					  const std::string &color_selection)
 {
-#define SET_COLOR(key,value) gconf_client_set_string (gconf_client, GCONF_ROOT "/FormEditor/Colors/" key, value.c_str (), 0)
+#define SET_COLOR(key,value) gconf_client->set (GCONF_ROOT "/FormEditor/Colors/", value)
 
     SET_COLOR("foreground", color_fg);
     SET_COLOR("foreground_disabled", color_disabled);
@@ -203,22 +151,12 @@ std::string Preferences::FormEditor::get_color_selection ()
     return get_gconf_string (GCONF_COLORS_ROOT "/selection");
 }
 
-static void Preferences::FormEditor::gconf_color_cb (GConfClient  *client,
-						     unsigned int  cnxn_id,
-						     GConfEntry   *entry,
-						     gpointer      user_data)
-{
-    colors_changed.emit ();
-}
-
 float Preferences::FormEditor::get_default_zoom ()
 {
-    return gconf_client_get_float (gconf_client, GCONF_ROOT "/FormEditor/default_zoom", 0);
+    return gconf_client->get_float (GCONF_ROOT "/FormEditor/default_zoom");
 }
 
 void Preferences::FormEditor::set_default_zoom (float default_zoom)
 {
-    gconf_client_set_float (gconf_client,
-			    GCONF_ROOT "/FormEditor/default_zoom",
-			    default_zoom, 0);
+    gconf_client->set (GCONF_ROOT "/FormEditor/default_zoom", default_zoom);
 }
