@@ -1,6 +1,6 @@
-//$Id: property-ops-resource.h,v 1.8 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: property-ops-resource.h,v 1.10 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -80,8 +80,8 @@ namespace Guikachu
 		property_t &prop = prop_holder.get_member (*resource);
 		
 		PropChangeOp<value_t> *new_op = new PropChangeOp<value_t> (
-		    label, resource, prop, op->new_val, true);
-		new_op->old_val = old_val;
+		    this->label, resource, prop, op->new_val, true);
+		new_op->old_val = this->old_val;
 		
 		return new_op;
 	    }
