@@ -1,6 +1,6 @@
-//$Id: resource-ref.h,v 1.13 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: resource-ref.h,v 1.15 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -21,18 +21,19 @@
 
 #include "property.h"
 #include "resource.h"
-#include <sigc++/object.h>
+#include <sigc++/trackable.h>
+#include <sigc++/connection.h>
 
 namespace Guikachu
 {
     namespace Properties
     {
 	class ResourceRef: public Property<std::string>,
-			   public SigC::Object
+			   public sigc::trackable
 	{
 	    ResourceManager  *manager;
 	    Resource         *current_resource;
-	    SigC::Connection  current_resource_changed;
+	    sigc::connection  current_resource_changed;
 	    
 	public:
 	    ResourceRef (notify_signal_t   &notify_signal,
@@ -45,7 +46,7 @@ namespace Guikachu
             ResourceManager * get_manager () const { return manager; };
             Resource *        resolve () const { return current_resource; };
 
-	    SigC::Signal0<void> resource_changed;
+	    sigc::signal0<void> resource_changed;
 	    
 	private:
 	    void resource_created_cb (Resource *res);
