@@ -1,6 +1,6 @@
-//$Id: resource-tree-treedata.cc,v 1.2 2004/08/14 15:35:35 cactus Exp $ -*- c++ -*-
+//$Id: resource-tree-treedata.cc,v 1.5 2005/10/03 08:44:46 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -110,21 +110,29 @@ void ResourceTree::TreeData::apply_to_cell (Gtk::CellRenderer *cell) const
     CellRendererIconText *cell_icontext = dynamic_cast<CellRendererIconText*> (cell);
     g_return_if_fail (cell_icontext);
 
-    cell_icontext->property_text () = get_label ();
-
     switch (type)
     {
     case TREEDATA_CATEGORY:
+        cell_icontext->property_text () = get_label ();    
         cell_icontext->property_weight () = Pango::WEIGHT_BOLD;
-        cell_icontext->property_pixbuf () = Glib::RefPtr<Gdk::Pixbuf> ();
+        cell_icontext->property_pixbuf () = Glib::RefPtr<Gdk::Pixbuf> ();        
         //cell_icontext->property_editable () = false;
         break;
     case TREEDATA_APP:
-        cell_icontext->property_weight () = Pango::WEIGHT_BOLD;
+        cell_icontext->property_weight_set () = false;
         cell_icontext->property_pixbuf () = Glib::RefPtr<Gdk::Pixbuf> ();
         //cell_icontext->property_editable () = true;
+
+        {
+            Glib::ustring app_name = Glib::Markup::escape_text (get_label ());
+            Glib::ScopedPtr<char> label (g_strdup_printf (_("<b>%s</b> <small>(double-click to edit)</small>"),
+                                                          app_name.c_str ()));
+            cell_icontext->property_markup () = label.get ();
+        }
+        
         break;
     case TREEDATA_RESOURCE:
+        cell_icontext->property_text () = get_label ();    
         cell_icontext->property_weight () = Pango::WEIGHT_NORMAL;
         cell_icontext->property_pixbuf () = Resources::get_type_pixbuf (res->get_type ());
         //cell_icontext->property_editable () = true;
