@@ -1,6 +1,6 @@
-//$Id: resource-tree.h,v 1.9 2004/06/27 11:06:11 cactus Exp $ -*- c++ -*-
+//$Id: resource-tree.h,v 1.12 2005/10/03 14:50:07 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -87,12 +87,15 @@ namespace Guikachu
 	    AppWindow *app_win;
 
             Gtk::Menu *popup_menu;
+
+            bool grouped;
 	    
 	public:
 	    ResourceTree ();
 	    ~ResourceTree ();
 
 	    void set_manager (ResourceManager *manager);
+            void set_grouped (bool grouped);
 
             Resource * get_selected ();
 
@@ -120,10 +123,14 @@ namespace Guikachu
             void res_cut_cb    (Resource *res);
             void res_copy_cb   (Resource *res);
             void res_remove_cb (Resource *res);
-	    
+
+            void reset ();
 	    void resource_created_cb (Resource *res);
 	    void resource_removed_cb (Resource *res);
 	    void resource_changed_cb (Gtk::TreeRow row);
+
+            Gtk::TreeStore::iterator get_place (Resource *res);
+            bool compare_treerow (const Gtk::TreeRow &row, Resource *res) const;
 	};
     }
 }
