@@ -1,6 +1,6 @@
-//$Id: session.cc,v 1.28 2004/08/22 21:01:56 cactus Exp $ -*- c++ -*-
+//$Id: session.cc,v 1.30 2005/10/01 10:36:17 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -102,8 +102,6 @@ Main::Main (int argc, char **argv):
 
 Main::~Main ()
 {
-    // Shut down preferences
-    Preferences::shutdown ();
 }
 
 void Main::run_impl ()
