@@ -1,6 +1,6 @@
-//$Id: storage-node.cc,v 1.25 2003/12/20 17:57:04 cactus Exp $ -*- c++ -*-
+//$Id: storage-node.cc,v 1.28 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -21,10 +21,12 @@
 #include "config.h"
 #include <libxml/xmlmemory.h>
 #include <glib.h>
-#include <libgnome/libgnome.h> // for gnome_i18n_get_language_list
+#include "gnome-i18n-cnp.h" // for get_language_list
 
 #include "storage.h"
 
+#include <glibmm/utility.h>
+
 using namespace Guikachu;
 
 StorageNode::StorageNode ():
@@ -49,7 +51,11 @@ StorageNode::StorageNode (xmlNodePtr node, Storage *parent_doc_):
 
 StorageNode StorageNode::children () const
 {
-    return StorageNode (node_ptr->xmlChildrenNode, parent_doc);
+    xmlNodePtr child_node;
+    for (child_node = node_ptr->xmlChildrenNode; child_node && child_node->type != XML_ELEMENT_NODE;
+	 child_node = child_node->next);
+    
+    return StorageNode (child_node, parent_doc);
 }
 
 StorageNode StorageNode::operator++ (int)
@@ -98,7 +104,7 @@ void StorageNode::set_content (const std::string &content)
     xmlNodeSetContent (node_ptr, (xmlChar*) content.c_str ());
 }
 
-std::string StorageNode::get_content_raw () const
+Glib::ustring StorageNode::get_content_raw () const
 {
     g_assert (node_ptr != 0);
     
@@ -117,40 +123,40 @@ std::string StorageNode::get_content_raw () const
 
 namespace
 {
-    bool escape_string (std::string &raw_str)
+    std::pair<bool, std::string> escape_string (const Glib::ustring &raw_str)
     {
 	std::string converted_str;
 	bool converted = false;
+
+	converted_str.reserve (raw_str.length ());
 	
-	for (std::string::const_iterator i = raw_str.begin (); i != raw_str.end (); ++i)
+	for (Glib::ustring::const_iterator i = raw_str.begin (); i != raw_str.end (); ++i)
 	{
 	    if ((signed char)*i < 0)
 	    {
 		converted = true;
 		
-		char *tmp = g_strdup_printf ("\\x%X", (unsigned char)*i);
-		converted_str += tmp;
-		g_free (tmp);
+		Glib::ScopedPtr<char> tmp (g_strdup_printf ("\\x%X", *i));
+		converted_str += tmp.get ();
 	    } else {
-		converted_str += *i;
+		converted_str += char (*i);
 	    }
 	}
 
-	if (converted)
-	    raw_str = converted_str;
-
-	return converted;
+	return std::make_pair (converted, converted_str);
     }
 }
 
 std::string StorageNode::get_content () const
 {
-    std::string ret_val = get_content_raw ();
+    Glib::ustring raw = get_content_raw ();
 
-    if (escape_string (ret_val) && parent_doc)
+    std::pair<bool, std::string> conversion_status = escape_string (raw);
+    
+    if (conversion_status.first && parent_doc)
 	parent_doc->encoding_notify.emit ();
     
-    return ret_val;
+    return conversion_status.second;
 }
 
 
@@ -169,9 +175,8 @@ void StorageNode::set_prop (const std::string &prop_name,
 {
     g_assert (node_ptr != 0);
 
-    char *tmp = g_strdup_printf ("%d", value);
-    set_prop (prop_name, tmp);
-    g_free (tmp);
+    Glib::ScopedPtr<char> tmp (g_strdup_printf ("%d", value));
+    set_prop (prop_name, tmp.get ());
 }
 
 void StorageNode::set_prop (const std::string &prop_name,
@@ -179,9 +184,8 @@ void StorageNode::set_prop (const std::string &prop_name,
 {
     g_assert (node_ptr != 0);
     
-    char *tmp = g_strdup_printf ("%d", value);
-    set_prop (prop_name, tmp);
-    g_free (tmp);
+    Glib::ScopedPtr<char> tmp (g_strdup_printf ("%d", value));
+    set_prop (prop_name, tmp.get ());
 }
 
 void StorageNode::set_prop (const std::string &prop_name,
@@ -204,11 +208,11 @@ void StorageNode::set_prop_bool (const std::string &prop_name,
     set_prop (prop_name, value ? "yes" : "no");
 }
 
-std::string StorageNode::get_prop_string_raw (const std::string &prop_name) const
+Glib::ustring StorageNode::get_prop_string_raw (const std::string &prop_name) const
 {
     g_assert (node_ptr != 0);
 
-    std::string ret;
+    Glib::ustring ret;
     
     xmlChar *xml_tmp = xmlGetProp (node_ptr, (xmlChar*) prop_name.c_str ());
 
@@ -223,12 +227,14 @@ std::string StorageNode::get_prop_string_raw (const std::string &prop_name) cons
 
 std::string StorageNode::get_prop_string (const std::string &prop_name) const
 {
-    std::string ret_val = get_prop_string_raw (prop_name);
-    
-    if (escape_string (ret_val) && parent_doc)
+    Glib::ustring raw = get_prop_string_raw (prop_name);
+
+    std::pair<bool, std::string> convert_status = escape_string (raw);
+
+    if (convert_status.first && parent_doc)
 	parent_doc->encoding_notify.emit ();
     
-    return ret_val;
+    return convert_status.second;
 }
 
 int StorageNode::get_prop_int (const std::string &prop_name) const
@@ -275,7 +281,11 @@ bool StorageNode::get_prop_bool (const std::string &prop_name) const
 
 StorageNode StorageNode::next () const
 {
-    return StorageNode (node_ptr->next, parent_doc);
+    xmlNodePtr next_node;
+    for (next_node = node_ptr->next; next_node && next_node->type != XML_ELEMENT_NODE;
+	 next_node = next_node->next);
+    
+    return StorageNode (next_node, parent_doc);
 }
 
 StorageNode StorageNode::get_translated_child (const std::string &name) const
@@ -284,7 +294,7 @@ StorageNode StorageNode::get_translated_child (const std::string &name) const
     
     StorageNode best_node (0, parent_doc);
 
-    GList *lang_list = gnome_i18n_get_language_list ("LC_MESSAGES");
+    const std::list<std::string> lang_list = get_language_list ("LC_MESSAGES");
     
     int best_score = INT_MAX;
     
@@ -293,18 +303,18 @@ StorageNode StorageNode::get_translated_child (const std::string &name) const
 	if (node.name () != name)
 	    continue;
 
-	xmlChar *lang = xmlNodeGetLang (node.c_node ());
+	char *lang = (char*)xmlNodeGetLang (node.c_node ());
 
 	if (lang != 0)
 	{
-	    GList *lang_list_i;
 	    int score;
-	    
-	    for (lang_list_i = lang_list, score = 0;
-		 lang_list_i != 0 && score < best_score;
-		 lang_list_i = lang_list_i->next, score++)
+
+	    std::list<std::string>::const_iterator i;
+	    for (i = lang_list.begin (), score = 0;
+		 i != lang_list.end () && score < best_score;
+		 ++i, ++best_score)
 	    {
-		if (strcmp ((char *)lang_list_i->data, (char*)lang) == 0)
+		if (*i == lang)
 		{
 		    best_node = node;
 		    best_score = score;
