@@ -1,6 +1,6 @@
-//$Id: storage.h,v 1.16 2004/08/20 18:22:17 cactus Exp $ -*- c++ -*-
+//$Id: storage.h,v 1.18 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -43,7 +43,7 @@ namespace Guikachu
 	void load        (const Glib::ustring &filename) throw (Glib::Exception); 
 	void load_uri    (const Glib::ustring &uri) throw (Glib::Exception);
 	void save_uri    (const Glib::ustring &uri) const throw (Glib::Exception);
-	void save_buffer (char *&buffer, Gnome::Vfs::FileSize &buffer_size) const;
+	void save_buffer (unsigned char *&buffer, Gnome::Vfs::FileSize &buffer_size) const;
 	
 	StorageNode get_root    ();
 	void        set_root    (StorageNode &root);
