@@ -1,6 +1,6 @@
-//$Id: ui-gui.cc,v 1.8 2004/08/16 12:19:12 cactus Exp $ -*- c++ -*-
+//$Id: ui-gui.cc,v 1.12 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -21,6 +21,7 @@
 
 #include "ui-gui.h"
 #include "session.h"
+#include "io/io.h"
 
 #include <gtkmm/alignment.h>
 #include <gtkmm/label.h>
@@ -51,6 +52,7 @@ void UI::show_about ()
     authors.push_back ("Gerg\xC5\x91 \xC3\x89rdi");
     authors.push_back ("Jay Bloodworth");
     authors.push_back ("Christopher Keith Fairbairn");
+    authors.push_back ("Tobias Gruetzmacher");
     authors.push_back ("Nathan Kurz");
 
     std::list<Glib::ustring> documenters;
@@ -110,9 +112,49 @@ Gtk::Button * UI::create_stock_button (const Gtk::StockID  &stock_id,
     Gtk::Alignment *alignment = new Gtk::Alignment (0.5, 0.5, 0, 0);
     Gtk::HBox *hbox = new Gtk::HBox (false, 2);
     hbox->pack_start (*manage (new Gtk::Image (stock_id, Gtk::ICON_SIZE_BUTTON)), Gtk::PACK_SHRINK);
-    hbox->pack_start (*manage (new Gtk::Label (title)), Gtk::PACK_SHRINK);
+    hbox->pack_start (*manage (new Gtk::Label (title, true)), Gtk::PACK_SHRINK);
     alignment->add (*manage (hbox));
-    
+
+    alignment->show_all ();
     button->add (*manage (alignment));
     return button;
 }
+
+bool UI::confirm_save (Gtk::FileChooserDialog &file_chooser)
+{
+    if (file_chooser.run () == Gtk::RESPONSE_ACCEPT)
+    {
+	Glib::ustring uri = file_chooser.get_uri ();
+	if (IO::uri_exists (uri))
+	{
+	    Glib::ScopedPtr<char> message (
+		g_strdup_printf (_("<b><big>\"%s\" already exists</big></b>\n"
+				   "Would you like to overwrite it?"),
+				 UI::visible_filename (uri).c_str ()));
+	    Gtk::MessageDialog *confirm = new Gtk::MessageDialog (file_chooser,
+								  message.get (), true,
+								  Gtk::MESSAGE_QUESTION,
+								  Gtk::BUTTONS_NONE,
+								  true);
+            Gtk::Button *overwrite_btn = UI::create_stock_button (Gtk::Stock::SAVE, _("Overwrite"));
+            overwrite_btn->show ();
+
+            confirm->add_button (Gtk::Stock::CANCEL, Gtk::RESPONSE_NO);
+            confirm->add_action_widget (*manage (overwrite_btn), Gtk::RESPONSE_YES);
+            confirm->set_default_response (Gtk::RESPONSE_NO);
+            
+            int response = confirm->run ();
+	    delete confirm;
+
+	    if (response == Gtk::RESPONSE_YES)
+		return true;
+	    else
+		return confirm_save (file_chooser);
+	    
+	} else {
+	    return true;
+	}
+    }
+    
+    return false;
+}
