@@ -1,6 +1,6 @@
-//$Id: ui.cc,v 1.2 2003/06/30 14:07:56 cactus Exp $ -*- c++ -*-
+//$Id: ui.cc,v 1.5 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -22,10 +22,12 @@
 
 using namespace Guikachu;
 
-std::string UI::visible_filename (const std::string &uri)
+Glib::ustring UI::visible_filename (const Glib::ustring &uri)
 {
+    // FIXME: Ensure UTF-8-safetiness
+    
     // Cut off path
-    std::string retval = g_basename (uri.c_str ());
+    Glib::ustring retval = g_basename (uri.c_str ());
 
     // If extension is .guikachu, cut that off as well
     static const char         *pattern = ".guikachu";
