@@ -1,6 +1,6 @@
-//$Id: pos-entry.cc,v 1.11 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: pos-entry.cc,v 1.13 2005/07/29 09:54:19 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -30,7 +30,7 @@ XPosEntry::XPosEntry (ResourceManager *manager,
     NumEntry (0, (manager->get_target ()->screen_width - 1), property, op_factory),
     target (manager->get_target ())
 {
-    target->changed.connect (SigC::slot (*this, &XPosEntry::target_changed_cb));
+    target->changed.connect (sigc::mem_fun (*this, &XPosEntry::target_changed_cb));
 }
 
 void XPosEntry::target_changed_cb ()
@@ -44,7 +44,7 @@ YPosEntry::YPosEntry (ResourceManager *manager,
     NumEntry (0, (manager->get_target ()->screen_height - 1), property, op_factory),
     target (manager->get_target ())
 {
-    target->changed.connect (SigC::slot (*this, &YPosEntry::target_changed_cb));
+    target->changed.connect (sigc::mem_fun (*this, &YPosEntry::target_changed_cb));
 }
 
 void YPosEntry::target_changed_cb ()
