@@ -1,6 +1,6 @@
-//$Id: target-combo.h,v 1.12 2004/08/31 12:50:40 cactus Exp $ -*- c++ -*-
+//$Id: target-combo.h,v 1.14 2005/07/29 09:54:19 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -32,8 +32,8 @@ namespace Guikachu
     {
 	namespace PropertyEditors
 	{
-	    class TargetCombo: public PropertyEditor,
-			       public Gtk::ComboBox
+	    class TargetCombo: public Gtk::ComboBox,
+                               public PropertyEditor
 	    {
 		ResourceManager *manager;
 		Target          *target;
